@@ -38,6 +38,7 @@
 #include <e-util/e-util.h>
 #include <e-util/e-alert-sink.h>
 #include <e-util/e-dialog-utils.h>
+#include <e-util/e-extensible.h>
 #include <e-util/e-util-private.h>
 #include <e-util/gconf-bridge.h>
 #include <shell/e-shell.h>
@@ -112,6 +113,14 @@ struct _CompEditorPrivate {
 	   below */
 	CompEditorFlags flags;
 
+	icaltimezone *zone;
+	gboolean use_24_hour_format;
+
+	gint work_day_end_hour;
+	gint work_day_end_minute;
+	gint work_day_start_hour;
+	gint work_day_start_minute;
+
 	gboolean changed;
 	gboolean needs_send;
 
@@ -131,7 +140,13 @@ enum {
 	PROP_FLAGS,
 	PROP_FOCUS_TRACKER,
 	PROP_SHELL,
-	PROP_SUMMARY
+	PROP_SUMMARY,
+	PROP_TIMEZONE,
+	PROP_USE_24_HOUR_FORMAT,
+	PROP_WORK_DAY_END_HOUR,
+	PROP_WORK_DAY_END_MINUTE,
+	PROP_WORK_DAY_START_HOUR,
+	PROP_WORK_DAY_START_MINUTE
 };
 
 static const gchar *ui =
@@ -195,7 +210,8 @@ static void obj_removed_cb (ECal *client, GList *uids, CompEditor *editor);
 
 G_DEFINE_TYPE_WITH_CODE (
 	CompEditor, comp_editor, GTK_TYPE_WINDOW,
-	G_IMPLEMENT_INTERFACE (E_TYPE_ALERT_SINK, NULL))
+	G_IMPLEMENT_INTERFACE (E_TYPE_ALERT_SINK, NULL);
+	G_IMPLEMENT_INTERFACE (E_TYPE_EXTENSIBLE, NULL))
 
 enum {
 	OBJECT_CREATED,
@@ -731,11 +747,12 @@ action_print_cb (GtkAction *action,
                  CompEditor *editor)
 {
 	CompEditorPrivate *priv = editor->priv;
-	GtkPrintOperationAction print_action;
 	ECalComponent *comp;
 	GList *l;
 	icalcomponent *component;
 	icalcomponent *clone;
+	icaltimezone *zone;
+	gboolean use_24_hour_format;
 
 	comp = e_cal_component_new ();
 	component = e_cal_component_get_icalcomponent (priv->comp);
@@ -745,8 +762,12 @@ action_print_cb (GtkAction *action,
 	for (l = priv->pages; l != NULL; l = l->next)
 		 comp_editor_page_fill_component (l->data, comp);
 
-	print_action = GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG;
-	print_comp (comp, priv->client, print_action);
+	zone = comp_editor_get_timezone (editor);
+	use_24_hour_format = comp_editor_get_use_24_hour_format (editor);
+
+	print_comp (
+		comp, priv->client, zone, use_24_hour_format,
+		GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG);
 
 	g_object_unref (comp);
 }
@@ -756,11 +777,12 @@ action_print_preview_cb (GtkAction *action,
                          CompEditor *editor)
 {
 	CompEditorPrivate *priv = editor->priv;
-	GtkPrintOperationAction print_action;
 	ECalComponent *comp;
 	GList *l;
 	icalcomponent *component;
 	icalcomponent *clone;
+	icaltimezone *zone;
+	gboolean use_24_hour_format;
 
 	comp = e_cal_component_new ();
 	component = e_cal_component_get_icalcomponent (priv->comp);
@@ -770,8 +792,12 @@ action_print_preview_cb (GtkAction *action,
 	for (l = priv->pages; l != NULL; l = l->next)
 		 comp_editor_page_fill_component (l->data, comp);
 
-	print_action = GTK_PRINT_OPERATION_ACTION_PREVIEW;
-	print_comp (comp, priv->client, print_action);
+	zone = comp_editor_get_timezone (editor);
+	use_24_hour_format = comp_editor_get_use_24_hour_format (editor);
+
+	print_comp (
+		comp, priv->client, zone, use_24_hour_format,
+		GTK_PRINT_OPERATION_ACTION_PREVIEW);
 
 	g_object_unref (comp);
 }
@@ -834,7 +860,7 @@ action_save_cb (GtkAction *action,
 
 	if (!e_cal_is_read_only (priv->client, &read_only, NULL) || read_only) {
 		e_alert_submit (
-			GTK_WIDGET (editor),
+			E_ALERT_SINK (editor),
 			"calendar:prompt-read-only-cal-editor",
 			e_source_peek_name (
 				e_cal_get_source (priv->client)),
@@ -1271,6 +1297,42 @@ comp_editor_set_property (GObject *object,
 				COMP_EDITOR (object),
 				g_value_get_string (value));
 			return;
+
+		case PROP_TIMEZONE:
+			comp_editor_set_timezone (
+				COMP_EDITOR (object),
+				g_value_get_pointer (value));
+			return;
+
+		case PROP_USE_24_HOUR_FORMAT:
+			comp_editor_set_use_24_hour_format (
+				COMP_EDITOR (object),
+				g_value_get_boolean (value));
+			return;
+
+		case PROP_WORK_DAY_END_HOUR:
+			comp_editor_set_work_day_end_hour (
+				COMP_EDITOR (object),
+				g_value_get_int (value));
+			return;
+
+		case PROP_WORK_DAY_END_MINUTE:
+			comp_editor_set_work_day_end_minute (
+				COMP_EDITOR (object),
+				g_value_get_int (value));
+			return;
+
+		case PROP_WORK_DAY_START_HOUR:
+			comp_editor_set_work_day_start_hour (
+				COMP_EDITOR (object),
+				g_value_get_int (value));
+			return;
+
+		case PROP_WORK_DAY_START_MINUTE:
+			comp_editor_set_work_day_start_minute (
+				COMP_EDITOR (object),
+				g_value_get_int (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -1318,6 +1380,42 @@ comp_editor_get_property (GObject *object,
 				value, comp_editor_get_summary (
 				COMP_EDITOR (object)));
 			return;
+
+		case PROP_TIMEZONE:
+			g_value_set_pointer (
+				value, comp_editor_get_timezone (
+				COMP_EDITOR (object)));
+			return;
+
+		case PROP_USE_24_HOUR_FORMAT:
+			g_value_set_boolean (
+				value, comp_editor_get_use_24_hour_format (
+				COMP_EDITOR (object)));
+			return;
+
+		case PROP_WORK_DAY_END_HOUR:
+			g_value_set_int (
+				value, comp_editor_get_work_day_end_hour (
+				COMP_EDITOR (object)));
+			return;
+
+		case PROP_WORK_DAY_END_MINUTE:
+			g_value_set_int (
+				value, comp_editor_get_work_day_end_minute (
+				COMP_EDITOR (object)));
+			return;
+
+		case PROP_WORK_DAY_START_HOUR:
+			g_value_set_int (
+				value, comp_editor_get_work_day_start_hour (
+				COMP_EDITOR (object)));
+			return;
+
+		case PROP_WORK_DAY_START_MINUTE:
+			g_value_set_int (
+				value, comp_editor_get_work_day_start_minute (
+				COMP_EDITOR (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -1400,6 +1498,16 @@ comp_editor_finalize (GObject *object)
 	G_OBJECT_CLASS (comp_editor_parent_class)->finalize (object);
 }
 
+static void
+comp_editor_constructed (GObject *object)
+{
+	e_extensible_load_extensions (E_EXTENSIBLE (object));
+
+	/* Chain up to parent's constructed() method. */
+	if (G_OBJECT_CLASS (comp_editor_parent_class)->constructed)
+		G_OBJECT_CLASS (comp_editor_parent_class)->constructed (object);
+}
+
 static void
 comp_editor_bind_gconf (CompEditor *editor)
 {
@@ -1527,6 +1635,7 @@ comp_editor_class_init (CompEditorClass *class)
 	object_class->get_property = comp_editor_get_property;
 	object_class->dispose = comp_editor_dispose;
 	object_class->finalize = comp_editor_finalize;
+	object_class->constructed = comp_editor_constructed;
 
 	widget_class = GTK_WIDGET_CLASS (class);
 	widget_class->delete_event = comp_editor_delete_event;
@@ -1605,14 +1714,81 @@ comp_editor_class_init (CompEditorClass *class)
 			NULL,
 			G_PARAM_READWRITE));
 
-	signals[OBJECT_CREATED] =
-		g_signal_new ("object_created",
-			      G_TYPE_FROM_CLASS (class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CompEditorClass, object_created),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+	g_object_class_install_property (
+		object_class,
+		PROP_TIMEZONE,
+		g_param_spec_pointer (
+			"timezone",
+			"Time Zone",
+			NULL,
+			G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_USE_24_HOUR_FORMAT,
+		g_param_spec_boolean (
+			"use-24-hour-format",
+			"Use 24-hour Format",
+			NULL,
+			FALSE,
+			G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_WORK_DAY_END_HOUR,
+		g_param_spec_int (
+			"work-day-end-hour",
+			"Work Day End Hour",
+			NULL,
+			0,
+			23,
+			0,
+			G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_WORK_DAY_END_MINUTE,
+		g_param_spec_int (
+			"work-day-end-minute",
+			"Work Day End Minute",
+			NULL,
+			0,
+			59,
+			0,
+			G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_WORK_DAY_START_HOUR,
+		g_param_spec_int (
+			"work-day-start-hour",
+			"Work Day Start Hour",
+			NULL,
+			0,
+			23,
+			0,
+			G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_WORK_DAY_START_MINUTE,
+		g_param_spec_int (
+			"work-day-start-minute",
+			"Work Day Start Minute",
+			NULL,
+			0,
+			59,
+			0,
+			G_PARAM_READWRITE));
+
+	signals[OBJECT_CREATED] = g_signal_new (
+		"object_created",
+		G_TYPE_FROM_CLASS (class),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (CompEditorClass, object_created),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__VOID,
+		G_TYPE_NONE, 0);
 }
 
 static void
@@ -1881,7 +2057,7 @@ prompt_and_save_changes (CompEditor *editor, gboolean send)
 	case GTK_RESPONSE_YES: /* Save */
 		if (!e_cal_is_read_only (priv->client, &read_only, NULL) || read_only) {
 			e_alert_submit (
-				GTK_WIDGET (editor),
+				E_ALERT_SINK (editor),
 				"calendar:prompt-read-only-cal-editor",
 				e_source_peek_name (
 					e_cal_get_source (priv->client)),
@@ -2091,6 +2267,120 @@ comp_editor_get_summary (CompEditor *editor)
 	return editor->priv->summary;
 }
 
+icaltimezone *
+comp_editor_get_timezone (CompEditor *editor)
+{
+	g_return_val_if_fail (IS_COMP_EDITOR (editor), NULL);
+
+	return editor->priv->zone;
+}
+
+void
+comp_editor_set_timezone (CompEditor *editor,
+                          icaltimezone *zone)
+{
+	g_return_if_fail (IS_COMP_EDITOR (editor));
+
+	editor->priv->zone = zone;
+
+	g_object_notify (G_OBJECT (editor), "timezone");
+}
+
+gboolean
+comp_editor_get_use_24_hour_format (CompEditor *editor)
+{
+	g_return_val_if_fail (IS_COMP_EDITOR (editor), FALSE);
+
+	return editor->priv->use_24_hour_format;
+}
+
+void
+comp_editor_set_use_24_hour_format (CompEditor *editor,
+                                    gboolean use_24_hour_format)
+{
+	g_return_if_fail (IS_COMP_EDITOR (editor));
+
+	editor->priv->use_24_hour_format = use_24_hour_format;
+
+	g_object_notify (G_OBJECT (editor), "use-24-hour-format");
+}
+
+gint
+comp_editor_get_work_day_end_hour (CompEditor *editor)
+{
+	g_return_val_if_fail (IS_COMP_EDITOR (editor), 0);
+
+	return editor->priv->work_day_end_hour;
+}
+
+void
+comp_editor_set_work_day_end_hour (CompEditor *editor,
+                                   gint work_day_end_hour)
+{
+	g_return_if_fail (IS_COMP_EDITOR (editor));
+
+	editor->priv->work_day_end_hour = work_day_end_hour;
+
+	g_object_notify (G_OBJECT (editor), "work-day-end-hour");
+}
+
+gint
+comp_editor_get_work_day_end_minute (CompEditor *editor)
+{
+	g_return_val_if_fail (IS_COMP_EDITOR (editor), 0);
+
+	return editor->priv->work_day_end_minute;
+}
+
+void
+comp_editor_set_work_day_end_minute (CompEditor *editor,
+                                     gint work_day_end_minute)
+{
+	g_return_if_fail (IS_COMP_EDITOR (editor));
+
+	editor->priv->work_day_end_minute = work_day_end_minute;
+
+	g_object_notify (G_OBJECT (editor), "work-day-end-minute");
+}
+
+gint
+comp_editor_get_work_day_start_hour (CompEditor *editor)
+{
+	g_return_val_if_fail (IS_COMP_EDITOR (editor), 0);
+
+	return editor->priv->work_day_start_hour;
+}
+
+void
+comp_editor_set_work_day_start_hour (CompEditor *editor,
+                                     gint work_day_start_hour)
+{
+	g_return_if_fail (IS_COMP_EDITOR (editor));
+
+	editor->priv->work_day_start_hour = work_day_start_hour;
+
+	g_object_notify (G_OBJECT (editor), "work-day-start-hour");
+}
+
+gint
+comp_editor_get_work_day_start_minute (CompEditor *editor)
+{
+	g_return_val_if_fail (IS_COMP_EDITOR (editor), 0);
+
+	return editor->priv->work_day_start_minute;
+}
+
+void
+comp_editor_set_work_day_start_minute (CompEditor *editor,
+                                       gint work_day_start_minute)
+{
+	g_return_if_fail (IS_COMP_EDITOR (editor));
+
+	editor->priv->work_day_start_minute = work_day_start_minute;
+
+	g_object_notify (G_OBJECT (editor), "work-day-start-minute");
+}
+
 /**
  * comp_editor_set_changed:
  * @editor: A component editor
@@ -3142,4 +3432,3 @@ obj_removed_cb (ECal *client,
 	if (changed_component_dialog ((GtkWindow *) editor, priv->comp, TRUE, priv->changed))
 		close_dialog (editor);
 }
-
