@@ -39,10 +39,7 @@
 #include <math.h>
 #include <string.h>
 #include "gnome-canvas-text.h"
-#include <pango/pangoft2.h>
 
-#include <libart_lgpl/art_affine.h>
-#include <libart_lgpl/art_rgb.h>
 #include "gnome-canvas-util.h"
 #include "gnome-canvas-i18n.h"
 
@@ -79,7 +76,6 @@ enum {
 	PROP_SCALE,         PROP_SCALE_SET,
 
 	/* Clipping */
-	PROP_ANCHOR,
 	PROP_JUSTIFICATION,
 	PROP_CLIP_WIDTH,
 	PROP_CLIP_HEIGHT,
@@ -91,21 +87,15 @@ enum {
 	PROP_FILL_COLOR,
 	PROP_FILL_COLOR_GDK,
 	PROP_FILL_COLOR_RGBA,
-	PROP_FILL_STIPPLE,
 
 	/* Rendered size accessors */
 	PROP_TEXT_WIDTH,
 	PROP_TEXT_HEIGHT
 };
 
-struct _GnomeCanvasTextPrivate {
-	guint render_dirty : 1;
-	FT_Bitmap bitmap;
-};
-
 static void gnome_canvas_text_class_init (GnomeCanvasTextClass *class);
 static void gnome_canvas_text_init (GnomeCanvasText *text);
-static void gnome_canvas_text_destroy (GnomeCanvasItem *object);
+static void gnome_canvas_text_dispose (GnomeCanvasItem *object);
 static void gnome_canvas_text_set_property (GObject            *object,
 					    guint               param_id,
 					    const GValue       *value,
@@ -115,21 +105,16 @@ static void gnome_canvas_text_get_property (GObject            *object,
 					    GValue             *value,
 					    GParamSpec         *pspec);
 
-static void gnome_canvas_text_update (GnomeCanvasItem *item, gdouble *affine,
-				      ArtSVP *clip_path, gint flags);
-static void gnome_canvas_text_realize (GnomeCanvasItem *item);
-static void gnome_canvas_text_unrealize (GnomeCanvasItem *item);
+static void gnome_canvas_text_update (GnomeCanvasItem *item, const cairo_matrix_t *matrix, gint flags);
 static void gnome_canvas_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 				    gint x, gint y, gint width, gint height);
-static gdouble gnome_canvas_text_point (GnomeCanvasItem *item,
-				       gdouble x,
-				       gdouble y,
-				       gint cx,
-				       gint cy,
-				       GnomeCanvasItem **actual_item);
+static GnomeCanvasItem *gnome_canvas_text_point (GnomeCanvasItem *item,
+                                                 gdouble x,
+                                                 gdouble y,
+                                                 gint cx,
+                                                 gint cy);
 static void gnome_canvas_text_bounds (GnomeCanvasItem *item,
 				      gdouble *x1, gdouble *y1, gdouble *x2, gdouble *y2);
-static void gnome_canvas_text_render (GnomeCanvasItem *item, GnomeCanvasBuf *buf);
 
 static void gnome_canvas_text_set_markup (GnomeCanvasText *textitem,
 					  const gchar     *markup);
@@ -197,7 +182,6 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 	gobject_class->set_property = gnome_canvas_text_set_property;
 	gobject_class->get_property = gnome_canvas_text_get_property;
 
-
 	/* Text */
         g_object_class_install_property
                 (gobject_class,
@@ -373,13 +357,6 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 				      1.0,
 				      G_PARAM_READABLE | G_PARAM_WRITABLE));
 
-        g_object_class_install_property
-		(gobject_class,
-                 PROP_ANCHOR,
-                 g_param_spec_enum ("anchor", NULL, NULL,
-                                    GTK_TYPE_ANCHOR_TYPE,
-                                    GTK_ANCHOR_CENTER,
-                                    (G_PARAM_READABLE | G_PARAM_WRITABLE)));
         g_object_class_install_property
                 (gobject_class,
                  PROP_JUSTIFICATION,
@@ -424,7 +401,7 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 				      "Color",
 				      "Text color, as string",
                                       NULL,
-                                      (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+                                      G_PARAM_WRITABLE));
         g_object_class_install_property
                 (gobject_class,
                  PROP_FILL_COLOR_GDK,
@@ -432,7 +409,7 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 				     "Color",
 				     "Text color, as a GdkColor",
 				     GDK_TYPE_COLOR,
-				     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+				     G_PARAM_WRITABLE));
         g_object_class_install_property
                 (gobject_class,
                  PROP_FILL_COLOR_RGBA,
@@ -441,12 +418,6 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 				    "Text color, as an R/G/B/A combined integer",
 				    0, G_MAXUINT, 0,
 				    (G_PARAM_READABLE | G_PARAM_WRITABLE)));
-        g_object_class_install_property
-                (gobject_class,
-                 PROP_FILL_STIPPLE,
-                 g_param_spec_object ("fill_stipple", NULL, NULL,
-                                      GDK_TYPE_DRAWABLE,
-                                      (G_PARAM_READABLE | G_PARAM_WRITABLE)));
         g_object_class_install_property
                 (gobject_class,
                  PROP_TEXT_WIDTH,
@@ -511,14 +482,11 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 		      "Whether this tag affects font scaling");
 #undef ADD_SET_PROP
 
-	item_class->destroy = gnome_canvas_text_destroy;
+	item_class->dispose = gnome_canvas_text_dispose;
 	item_class->update = gnome_canvas_text_update;
-	item_class->realize = gnome_canvas_text_realize;
-	item_class->unrealize = gnome_canvas_text_unrealize;
 	item_class->draw = gnome_canvas_text_draw;
 	item_class->point = gnome_canvas_text_point;
 	item_class->bounds = gnome_canvas_text_bounds;
-	item_class->render = gnome_canvas_text_render;
 }
 
 /* Object initialization function for the text item */
@@ -527,7 +495,6 @@ gnome_canvas_text_init (GnomeCanvasText *text)
 {
 	text->x = 0.0;
 	text->y = 0.0;
-	text->anchor = GTK_ANCHOR_CENTER;
 	text->justification = GTK_JUSTIFY_LEFT;
 	text->clip_width = 0.0;
 	text->clip_height = 0.0;
@@ -544,15 +511,11 @@ gnome_canvas_text_init (GnomeCanvasText *text)
 	text->underline_set = FALSE;
 	text->strike_set    = FALSE;
 	text->rise_set      = FALSE;
-
-	text->priv = g_new (GnomeCanvasTextPrivate, 1);
-	text->priv->bitmap.buffer = NULL;
-	text->priv->render_dirty = 1;
 }
 
-/* Destroy handler for the text item */
+/* Dispose handler for the text item */
 static void
-gnome_canvas_text_destroy (GnomeCanvasItem *object)
+gnome_canvas_text_dispose (GnomeCanvasItem *object)
 {
 	GnomeCanvasText *text;
 
@@ -560,36 +523,26 @@ gnome_canvas_text_destroy (GnomeCanvasItem *object)
 
 	text = GNOME_CANVAS_TEXT (object);
 
-	/* remember, destroy can be run multiple times! */
-
 	g_free (text->text);
 	text->text = NULL;
 
-	if (text->layout)
-	    g_object_unref (G_OBJECT (text->layout));
-	text->layout = NULL;
+	if (text->layout != NULL) {
+		g_object_unref (text->layout);
+		text->layout = NULL;
+	}
 
-	if (text->font_desc) {
+	if (text->font_desc != NULL) {
 		pango_font_description_free (text->font_desc);
 		text->font_desc = NULL;
 	}
 
-	if (text->attr_list)
+	if (text->attr_list != NULL) {
 		pango_attr_list_unref (text->attr_list);
-	text->attr_list = NULL;
-
-	if (text->stipple)
-		g_object_unref (text->stipple);
-	text->stipple = NULL;
-
-	if (text->priv && text->priv->bitmap.buffer) {
-		g_free (text->priv->bitmap.buffer);
+		text->attr_list = NULL;
 	}
-	g_free (text->priv);
-	text->priv = NULL;
 
-	if (GNOME_CANVAS_ITEM_CLASS (parent_class)->destroy)
-		GNOME_CANVAS_ITEM_CLASS (parent_class)->destroy (object);
+	if (GNOME_CANVAS_ITEM_CLASS (parent_class)->dispose)
+		GNOME_CANVAS_ITEM_CLASS (parent_class)->dispose (object);
 }
 
 static void
@@ -619,56 +572,6 @@ get_bounds (GnomeCanvasText *text,
 	text->clip_cwidth = text->clip_width * item->canvas->pixels_per_unit;
 	text->clip_cheight = text->clip_height * item->canvas->pixels_per_unit;
 
-	/* Anchor text */
-
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_SW:
-		break;
-
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_S:
-		text->cx -= text->max_width / 2;
-		text->clip_cx -= text->clip_cwidth / 2;
-		break;
-
-	case GTK_ANCHOR_NE:
-	case GTK_ANCHOR_E:
-	case GTK_ANCHOR_SE:
-		text->cx -= text->max_width;
-		text->clip_cx -= text->clip_cwidth;
-		break;
-
-	default:
-		break;
-	}
-
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_NE:
-		break;
-
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_E:
-		text->cy -= text->height / 2;
-		text->clip_cy -= text->clip_cheight / 2;
-		break;
-
-	case GTK_ANCHOR_SW:
-	case GTK_ANCHOR_S:
-	case GTK_ANCHOR_SE:
-		text->cy -= text->height;
-		text->clip_cy -= text->clip_cheight;
-		break;
-
-	default:
-		break;
-	}
-
 	/* Bounds */
 
 	if (text->clip) {
@@ -684,39 +587,6 @@ get_bounds (GnomeCanvasText *text,
 	}
 }
 
-/* Convenience function to set the text's GC's foreground color */
-static void
-set_text_gc_foreground (GnomeCanvasText *text)
-{
-	GdkColor c;
-
-	if (!text->gc)
-		return;
-
-	c.pixel = text->pixel;
-	gdk_gc_set_foreground (text->gc, &c);
-}
-
-/* Sets the stipple pattern for the text */
-static void
-set_stipple (GnomeCanvasText *text, GdkBitmap *stipple, gint reconfigure)
-{
-	if (text->stipple && !reconfigure)
-		g_object_unref (text->stipple);
-
-	text->stipple = stipple;
-	if (stipple && !reconfigure)
-		g_object_ref (stipple);
-
-	if (text->gc) {
-		if (stipple) {
-			gdk_gc_set_stipple (text->gc, stipple);
-			gdk_gc_set_fill (text->gc, GDK_STIPPLED);
-		} else
-			gdk_gc_set_fill (text->gc, GDK_SOLID);
-	}
-}
-
 static PangoFontMask
 get_property_font_set_mask (guint prop_id)
 {
@@ -755,10 +625,7 @@ gnome_canvas_text_set_property (GObject            *object,
 {
 	GnomeCanvasItem *item;
 	GnomeCanvasText *text;
-	GdkColor color = { 0, 0, 0, 0, };
 	GdkColor *pcolor;
-	gboolean color_changed;
-	gint have_pixel;
 	PangoAlignment align;
 
 	g_return_if_fail (object != NULL);
@@ -767,50 +634,8 @@ gnome_canvas_text_set_property (GObject            *object,
 	item = GNOME_CANVAS_ITEM (object);
 	text = GNOME_CANVAS_TEXT (object);
 
-	color_changed = FALSE;
-	have_pixel = FALSE;
-
-	if (!text->layout) {
-
-		PangoContext *gtk_context, *context;
-		gtk_context = gtk_widget_get_pango_context (GTK_WIDGET (item->canvas));
-
-		if (item->canvas->aa)  {
-			PangoFontMap *fontmap;
-			PangoLanguage *language;
-			gint	pixels, mm;
-			gdouble	dpi_x;
-			gdouble	dpi_y;
-
-			pixels = gdk_screen_width ();
-			mm = gdk_screen_width_mm ();
-			dpi_x = (((gdouble) pixels * 25.4) / (gdouble) mm);
-
-			pixels = gdk_screen_height ();
-			mm = gdk_screen_height_mm ();
-			dpi_y = (((gdouble) pixels * 25.4) / (gdouble) mm);
-
-			/* XXX This used to call pango_ft2_get_context().
-			 *     Is there a better way to do this? */
-			fontmap = pango_ft2_font_map_new ();
-			pango_ft2_font_map_set_resolution (PANGO_FT2_FONT_MAP (fontmap), dpi_x, dpi_y);
-			context = pango_font_map_create_context (fontmap);
-
-			language = pango_context_get_language (gtk_context);
-			pango_context_set_language (context, language);
-			pango_context_set_base_dir (context,
-						    pango_context_get_base_dir (gtk_context));
-			pango_context_set_font_description (context,
-							    pango_context_get_font_description (gtk_context));
-
-		} else
-			context = gtk_context;
-
-		text->layout = pango_layout_new (context);
-
-		if (item->canvas->aa)
-			g_object_unref (G_OBJECT (context));
-	}
+	if (!text->layout)
+                text->layout = pango_layout_new (gtk_widget_get_pango_context (GTK_WIDGET (item->canvas)));
 
 	switch (param_id) {
 	case PROP_TEXT:
@@ -819,13 +644,11 @@ gnome_canvas_text_set_property (GObject            *object,
 		text->text = g_value_dup_string (value);
 		pango_layout_set_text (text->layout, text->text, -1);
 
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_MARKUP:
 		gnome_canvas_text_set_markup (text,
 					      g_value_get_string (value));
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_X:
@@ -899,7 +722,6 @@ gnome_canvas_text_set_property (GObject            *object,
 		}
 
 		gnome_canvas_text_apply_font_desc (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_FAMILY_SET:
@@ -918,14 +740,12 @@ gnome_canvas_text_set_property (GObject            *object,
 		text->scale_set = TRUE;
 
 		gnome_canvas_text_apply_font_desc (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_SCALE_SET:
 		text->scale_set = g_value_get_boolean (value);
 
 		gnome_canvas_text_apply_font_desc (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_UNDERLINE:
@@ -933,14 +753,12 @@ gnome_canvas_text_set_property (GObject            *object,
 		text->underline_set = TRUE;
 
 		gnome_canvas_text_apply_attributes (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_UNDERLINE_SET:
 		text->underline_set = g_value_get_boolean (value);
 
 		gnome_canvas_text_apply_attributes (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_STRIKETHROUGH:
@@ -948,14 +766,12 @@ gnome_canvas_text_set_property (GObject            *object,
 		text->strike_set = TRUE;
 
 		gnome_canvas_text_apply_attributes (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_STRIKETHROUGH_SET:
 		text->strike_set = g_value_get_boolean (value);
 
 		gnome_canvas_text_apply_attributes (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_RISE:
@@ -963,14 +779,12 @@ gnome_canvas_text_set_property (GObject            *object,
 		text->rise_set = TRUE;
 
 		gnome_canvas_text_apply_attributes (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_RISE_SET:
 		text->rise_set = TRUE;
 
 		gnome_canvas_text_apply_attributes (text);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_ATTRIBUTES:
@@ -981,11 +795,6 @@ gnome_canvas_text_set_property (GObject            *object,
 		pango_attr_list_ref (text->attr_list);
 
 		gnome_canvas_text_apply_attributes (text);
-		text->priv->render_dirty = 1;
-		break;
-
-	case PROP_ANCHOR:
-		text->anchor = g_value_get_enum (value);
 		break;
 
 	case PROP_JUSTIFICATION:
@@ -1007,22 +816,18 @@ gnome_canvas_text_set_property (GObject            *object,
 			break;
 		}
 		pango_layout_set_alignment (text->layout, align);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_CLIP_WIDTH:
 		text->clip_width = fabs (g_value_get_double (value));
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_CLIP_HEIGHT:
 		text->clip_height = fabs (g_value_get_double (value));
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_CLIP:
 		text->clip = g_value_get_boolean (value);
-		text->priv->render_dirty = 1;
 		break;
 
 	case PROP_X_OFFSET:
@@ -1038,44 +843,31 @@ gnome_canvas_text_set_property (GObject            *object,
 
 		color_name = g_value_get_string (value);
 		if (color_name) {
+                        GdkColor color;
 			gdk_color_parse (color_name, &color);
 
 			text->rgba = ((color.red & 0xff00) << 16 |
 				      (color.green & 0xff00) << 8 |
 				      (color.blue & 0xff00) |
 				      0xff);
-			color_changed = TRUE;
 		}
-		text->priv->render_dirty = 1;
 		break;
 	}
 
 	case PROP_FILL_COLOR_GDK:
 		pcolor = g_value_get_boxed (value);
 		if (pcolor) {
-		    GdkColormap *colormap;
-
-		    color = *pcolor;
-		    colormap = gtk_widget_get_colormap (GTK_WIDGET (item->canvas));
-		    gdk_rgb_find_color (colormap, &color);
-		    have_pixel = TRUE;
-		}
-
-		text->rgba = ((color.red & 0xff00) << 16 |
-			      (color.green & 0xff00) << 8|
-			      (color.blue & 0xff00) |
-			      0xff);
-		color_changed = TRUE;
+                        text->rgba = ((pcolor->red & 0xff00) << 16 |
+                                      (pcolor->green & 0xff00) << 8|
+                                      (pcolor->blue & 0xff00) |
+                                      0xff);
+                } else {
+                        text->rgba = 0;
+                }
 		break;
 
         case PROP_FILL_COLOR_RGBA:
 		text->rgba = g_value_get_uint (value);
-		color_changed = TRUE;
-		text->priv->render_dirty = 1;
-		break;
-
-	case PROP_FILL_STIPPLE:
-		set_stipple (text, (GdkBitmap *)g_value_get_object (value), FALSE);
 		break;
 
 	default:
@@ -1083,16 +875,6 @@ gnome_canvas_text_set_property (GObject            *object,
 		break;
 	}
 
-	if (color_changed) {
-		if (have_pixel)
-			text->pixel = color.pixel;
-		else
-			text->pixel = gnome_canvas_get_color_pixel (item->canvas, text->rgba);
-
-		if (!item->canvas->aa)
-			set_text_gc_foreground (text);
-	}
-
 	/* Calculate text dimensions */
 
 	if (text->layout)
@@ -1244,10 +1026,6 @@ gnome_canvas_text_get_property (GObject            *object,
 		g_value_set_boxed (value, text->attr_list);
 		break;
 
-	case PROP_ANCHOR:
-		g_value_set_enum (value, text->anchor);
-		break;
-
 	case PROP_JUSTIFICATION:
 		g_value_set_enum (value, text->justification);
 		break;
@@ -1272,31 +1050,10 @@ gnome_canvas_text_get_property (GObject            *object,
 		g_value_set_double (value, text->yofs);
 		break;
 
-	case PROP_FILL_COLOR:
-		g_value_take_string (value,
-				     g_strdup_printf ("#%02x%02x%02x",
-				     text->rgba >> 24,
-				     (text->rgba >> 16) & 0xff,
-				     (text->rgba >> 8) & 0xff));
-		break;
-
-	case PROP_FILL_COLOR_GDK: {
-		GnomeCanvas *canvas = GNOME_CANVAS_ITEM (text)->canvas;
-		GdkColormap *colormap = gtk_widget_get_colormap (GTK_WIDGET (canvas));
-		GdkColor color;
-
-		gdk_colormap_query_color (colormap, text->pixel, &color);
-		g_value_set_boxed (value, &color);
-		break;
-	}
 	case PROP_FILL_COLOR_RGBA:
 		g_value_set_uint (value, text->rgba);
 		break;
 
-	case PROP_FILL_STIPPLE:
-		g_value_set_object (value, text->stipple);
-		break;
-
 	case PROP_TEXT_WIDTH:
 		g_value_set_double (value, text->max_width / text->item.canvas->pixels_per_unit);
 		break;
@@ -1375,7 +1132,6 @@ gnome_canvas_text_set_font_desc (GnomeCanvasText      *text,
 		text->font_desc = NULL;
 
 	gnome_canvas_text_apply_font_desc (text);
-	text->priv->render_dirty = 1;
 }
 
 /* Setting the text from a Pango markup string */
@@ -1413,8 +1169,7 @@ gnome_canvas_text_set_markup (GnomeCanvasText *textitem,
 /* Update handler for the text item */
 static void
 gnome_canvas_text_update (GnomeCanvasItem *item,
-                          gdouble *affine,
-                          ArtSVP *clip_path,
+                          const cairo_matrix_t *matrix,
                           gint flags)
 {
 	GnomeCanvasText *text;
@@ -1423,10 +1178,8 @@ gnome_canvas_text_update (GnomeCanvasItem *item,
 	text = GNOME_CANVAS_TEXT (item);
 
 	if (parent_class->update)
-		(* parent_class->update) (item, affine, clip_path, flags);
+		(* parent_class->update) (item, matrix, flags);
 
-	set_text_gc_foreground (text);
-	set_stipple (text, text->stipple, TRUE);
 	get_bounds (text, &x1, &y1, &x2, &y2);
 
 	gnome_canvas_update_bbox (item,
@@ -1434,208 +1187,56 @@ gnome_canvas_text_update (GnomeCanvasItem *item,
 				  ceil (x2), ceil (y2));
 }
 
-/* Realize handler for the text item */
-static void
-gnome_canvas_text_realize (GnomeCanvasItem *item)
-{
-	GtkLayout *layout;
-	GdkWindow *bin_window;
-	GnomeCanvasText *text;
-
-	text = GNOME_CANVAS_TEXT (item);
-
-	if (parent_class->realize)
-		(* parent_class->realize) (item);
-
-	layout = GTK_LAYOUT (item->canvas);
-	bin_window = gtk_layout_get_bin_window (layout);
-
-	text->gc = gdk_gc_new (bin_window);
-}
-
-/* Unrealize handler for the text item */
-static void
-gnome_canvas_text_unrealize (GnomeCanvasItem *item)
-{
-	GnomeCanvasText *text;
-
-	text = GNOME_CANVAS_TEXT (item);
-
-	g_object_unref (text->gc);
-	text->gc = NULL;
-
-	if (parent_class->unrealize)
-		(* parent_class->unrealize) (item);
-}
-
 /* Draw handler for the text item */
 static void
 gnome_canvas_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 			gint x, gint y, gint width, gint height)
 {
-	GnomeCanvasText *text;
-	GdkRectangle rect;
-
-	text = GNOME_CANVAS_TEXT (item);
+	GnomeCanvasText *text = GNOME_CANVAS_TEXT (item);
+        cairo_t *cr;
 
 	if (!text->text)
 		return;
 
-	if (text->clip) {
-		rect.x = text->clip_cx - x;
-		rect.y = text->clip_cy - y;
-		rect.width = text->clip_cwidth;
-		rect.height = text->clip_cheight;
-
-		gdk_gc_set_clip_rectangle (text->gc, &rect);
+        cr = gdk_cairo_create (drawable);
+        if (text->clip) {
+                cairo_rectangle (cr,
+                                 text->clip_cx - x,
+                                 text->clip_cy - y,
+                                 text->clip_cwidth,
+                                 text->clip_cheight);
+                cairo_clip (cr);
 	}
 
-	if (text->stipple)
-		gnome_canvas_set_stipple_origin (item->canvas, text->gc);
+        cairo_set_source_rgba (cr,
+                               ((text->rgba >> 24) & 0xff) / 255.0,
+                               ((text->rgba >> 16) & 0xff) / 255.0,
+                               ((text->rgba >>  8) & 0xff) / 255.0,
+                               ( text->rgba        & 0xff) / 255.0);
 
-	gdk_draw_layout (drawable, text->gc, text->cx - x, text->cy - y, text->layout);
+        cairo_move_to (cr, text->cx - x, text->cy - y);
+        pango_cairo_show_layout (cr, text->layout);
 
-	if (text->clip)
-		gdk_gc_set_clip_rectangle (text->gc, NULL);
-}
-
-/* Render handler for the text item */
-static void
-gnome_canvas_text_render (GnomeCanvasItem *item, GnomeCanvasBuf *buf)
-{
-	GnomeCanvasText *text;
-	guint32 fg_color;
-	gint render_x = 0, render_y = 0; /* offsets for text rendering,
-					 * for clipping rectangles */
-	gint x, y;
-	gint w, h;
-	guchar *dst, *src;
-	gint src_dx, src_dy;
-	gint i, alpha;
-	gint bm_rows, bm_width;
-
-	text = GNOME_CANVAS_TEXT (item);
-
-	if (!text->text)
-		return;
-
-	fg_color = text->rgba;
-
-        gnome_canvas_buf_ensure_buf (buf);
-
-	bm_rows = (text->clip) ? text->clip_cheight : text->height;
-	bm_width = (text->clip) ? text->clip_cwidth : text->max_width;
-	if (text->priv->render_dirty ||
-	   bm_rows != text->priv->bitmap.rows ||
-	   bm_width != text->priv->bitmap.width) {
-		if (text->priv->bitmap.buffer) {
-			g_free (text->priv->bitmap.buffer);
-		}
-		text->priv->bitmap.rows =  bm_rows;
-		text->priv->bitmap.width = bm_width;
-		text->priv->bitmap.pitch = (text->priv->bitmap.width+3)&~3;
-		text->priv->bitmap.buffer = g_malloc0 (
-			text->priv->bitmap.rows * text->priv->bitmap.pitch);
-		text->priv->bitmap.num_grays = 256;
-		text->priv->bitmap.pixel_mode = ft_pixel_mode_grays;
-
-		/* What this does is when a clipping rectangle is
-		   being used shift the rendering of the text by the
-		   correct amount so that the correct result is
-		   obtained as if all text was rendered, then clipped.
-		   In this sense we can use smaller buffers and less
-		   rendeirng since hopefully FreeType2 checks to see
-		   if the glyph falls in the bounding box before
-		   rasterizing it. */
-
-		if (text->clip) {
-			render_x = text->cx - text->clip_cx;
-			render_y = text->cy - text->clip_cy;
-		}
-
-		pango_ft2_render_layout (&text->priv->bitmap, text->layout, render_x, render_y);
-
-		text->priv->render_dirty = 0;
-	}
-
-	if (text->clip) {
-		x = text->clip_cx - buf->rect.x0;
-		y = text->clip_cy - buf->rect.y0;
-	} else {
-		x = text->cx - buf->rect.x0;
-		y = text->cy - buf->rect.y0;
-	}
-
-	w = text->priv->bitmap.width;
-	h = text->priv->bitmap.rows;
-
-	src_dx = src_dy = 0;
-
-	if (x + w > buf->rect.x1 - buf->rect.x0) {
-		w = buf->rect.x1 - buf->rect.x0 - x;
-	}
-
-	if (y + h > buf->rect.y1 - buf->rect.y0) {
-		h = buf->rect.y1 - buf->rect.y0 - y;
-	}
-
-	if (x < 0) {
-		w -= - x;
-		src_dx += - x;
-		x = 0;
-	}
-
-	if (y < 0) {
-		h -= -y;
-		src_dy += - y;
-		y = 0;
-	}
-
-	dst = buf->buf + y * buf->buf_rowstride + x * 3;
-	src = text->priv->bitmap.buffer +
-		src_dy * text->priv->bitmap.pitch + src_dx;
-	while (h-- > 0) {
-		i = w;
-		while (i-- > 0) {
-			/* FIXME: Do the libart thing instead of divide by 255 */
-			alpha = ((fg_color & 0xff) * (*src)) / 255;
-			dst[0] = (dst[0] * (255 - alpha) + ((fg_color >> 24) & 0xff) * alpha) / 255;
-			dst[1] = (dst[1] * (255 - alpha) + ((fg_color >> 16) & 0xff) * alpha) / 255;
-			dst[2] = (dst[2] * (255 - alpha) + ((fg_color >> 8) & 0xff) * alpha) / 255;
-			dst += 3;
-			src += 1;
-		}
-		dst += buf->buf_rowstride - w*3;
-		src += text->priv->bitmap.pitch - w;
-	}
-
-	buf->is_bg = 0;
-	return;
+        cairo_destroy (cr);
 }
 
 /* Point handler for the text item */
-static double
+static GnomeCanvasItem *
 gnome_canvas_text_point (GnomeCanvasItem *item, gdouble x, gdouble y,
-			 gint cx, gint cy, GnomeCanvasItem **actual_item)
+			 gint cx, gint cy)
 {
 	GnomeCanvasText *text;
 	PangoLayoutIter *iter;
 	gint x1, y1, x2, y2;
-	gint dx, dy;
-	gdouble dist, best;
 
 	text = GNOME_CANVAS_TEXT (item);
 
-	*actual_item = item;
-
 	/* The idea is to build bounding rectangles for each of the lines of
 	 * text (clipped by the clipping rectangle, if it is activated) and see
 	 * whether the point is inside any of these.  If it is, we are done.
 	 * Otherwise, calculate the distance to the nearest rectangle.
 	 */
 
-	best = 1.0e36;
-
 	iter = pango_layout_get_iter (text->layout);
 	do {
 		PangoRectangle log_rect;
@@ -1666,34 +1267,16 @@ gnome_canvas_text_point (GnomeCanvasItem *item, gdouble x, gdouble y,
 
 		/* Calculate distance from point to rectangle */
 
-		if (cx < x1)
-			dx = x1 - cx;
-		else if (cx >= x2)
-			dx = cx - x2 + 1;
-		else
-			dx = 0;
-
-		if (cy < y1)
-			dy = y1 - cy;
-		else if (cy >= y2)
-			dy = cy - y2 + 1;
-		else
-			dy = 0;
-
-		if ((dx == 0) && (dy == 0)) {
+		if (cx >= x1 && cx < x2 && cy >= y1 && cy < y2) {
 			pango_layout_iter_free (iter);
-			return 0.0;
+			return item;
 		}
 
-		dist = sqrt (dx * dx + dy * dy);
-		if (dist < best)
-			best = dist;
-
 	} while (pango_layout_iter_next_line (iter));
 
 	pango_layout_iter_free (iter);
 
-	return best / item->canvas->pixels_per_unit;
+	return NULL;
 }
 
 /* Bounds handler for the text item */
@@ -1720,50 +1303,6 @@ gnome_canvas_text_bounds (GnomeCanvasItem *item,
 		height = text->height / item->canvas->pixels_per_unit;
 	}
 
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_SW:
-		break;
-
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_S:
-		*x1 -= width / 2.0;
-		break;
-
-	case GTK_ANCHOR_NE:
-	case GTK_ANCHOR_E:
-	case GTK_ANCHOR_SE:
-		*x1 -= width;
-		break;
-
-	default:
-		break;
-	}
-
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_NE:
-		break;
-
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_E:
-		*y1 -= height / 2.0;
-		break;
-
-	case GTK_ANCHOR_SW:
-	case GTK_ANCHOR_S:
-	case GTK_ANCHOR_SE:
-		*y1 -= height;
-		break;
-
-	default:
-		break;
-	}
-
 	*x2 = *x1 + width;
 	*y2 = *y1 + height;
 }
