@@ -257,6 +257,9 @@ mail_backend_prepare_for_quit_cb (EShell *shell,
 
 	mail_vfolder_shutdown ();
 
+	/* Cancel all pending activities. */
+	mail_cancel_all ();
+
 	if (delete_junk)
 		e_mail_store_foreach (
 			(GHFunc) mail_backend_delete_junk, backend);
@@ -266,10 +269,7 @@ mail_backend_prepare_for_quit_cb (EShell *shell,
 
 	e_mail_store_foreach ((GHFunc) mail_backend_final_sync, &sync_data);
 
-	/* Cancel all activities. */
-	mail_cancel_all ();
-
-	/* Now we poll until all activities are actually cancelled.
+	/* Now we poll until all activities are actually cancelled or finished.
 	 * Reffing the activity delays quitting; the reference count
 	 * acts like a counting semaphore. */
 	if (mail_msg_active ())
@@ -520,6 +520,9 @@ mail_backend_constructed (GObject *object)
 	/* Defer initializing CamelStores until after the main loop
 	 * has started, so migration has a chance to run first. */
 	g_idle_add ((GSourceFunc) mail_backend_idle_cb, shell_backend);
+
+	if (G_OBJECT_CLASS (e_mail_backend_parent_class)->constructed)
+		G_OBJECT_CLASS (e_mail_backend_parent_class)->constructed (object);
 }
 
 static void
