@@ -21,10 +21,11 @@
  *
  */
 
-#ifndef __EM_COMPOSER_UTILS_H__
-#define __EM_COMPOSER_UTILS_H__
+#ifndef EM_COMPOSER_UTILS_H
+#define EM_COMPOSER_UTILS_H
 
 #include <em-format/em-format.h>
+#include <mail/e-mail-enums.h>
 #include <mail/e-mail-session.h>
 #include <composer/e-msg-composer.h>
 
@@ -43,58 +44,49 @@ void		em_utils_edit_messages		(EShell *shell,
 						 CamelFolder *folder,
 						 GPtrArray *uids,
 						 gboolean replace);
-void		em_utils_forward_attached	(EShell *shell,
-						 CamelFolder *folder,
-						 GPtrArray *uids,
-						 const gchar *from_uri);
-void		em_utils_forward_inline		(EShell *shell,
-						 CamelFolder *folder,
-						 GPtrArray *uids,
-						 const gchar *from_uri);
-void		em_utils_forward_quoted		(EShell *shell,
-						 CamelFolder *folder,
-						 GPtrArray *uids,
-						 const gchar *from_uri);
 EMsgComposer *	em_utils_forward_message	(EShell *shell,
 						 CamelMimeMessage *msg,
-						 const gchar *from_uri);
+						 const gchar *from_uri,
+						 EMailForwardStyle style);
 void		em_utils_forward_messages	(EShell *shell,
 						 CamelFolder *folder,
 						 GPtrArray *uids,
-						 const gchar *from_uri);
+						 const gchar *from_uri,
+						 EMailForwardStyle style);
 void		em_utils_redirect_message	(EShell *shell,
 						 CamelMimeMessage *message);
 void		em_utils_redirect_message_by_uid (EShell *shell,
 						 CamelFolder *folder,
 						 const gchar *uid);
-void		em_utils_forward_message_raw	(CamelFolder *folder,
-						 CamelMimeMessage *message,
-						 const gchar *address,
-						 GError **error);
 void		em_utils_handle_receipt		(EMailSession *session,
 						 CamelFolder *folder,
-						 const gchar *uid,
-						 CamelMimeMessage *msg);
+						 const gchar *message_uid,
+						 CamelMimeMessage *message);
 void		em_utils_send_receipt		(EMailSession *session,
 						 CamelFolder *folder,
 						 CamelMimeMessage *message);
-
-enum {
-	REPLY_MODE_SENDER, /* Reply-To?:From */
-	REPLY_MODE_FROM,
-	REPLY_MODE_ALL,
-	REPLY_MODE_LIST
-};
-
-gchar *em_utils_construct_composer_text (CamelMimeMessage *message, EMFormat *source);
-gboolean em_utils_is_munged_list_message (CamelMimeMessage *message);
-void em_utils_get_reply_sender (CamelMimeMessage *message, CamelInternetAddress *to, CamelNNTPAddress *postto);
-void em_utils_get_reply_all (CamelMimeMessage *message, CamelInternetAddress *to, CamelInternetAddress *cc, CamelNNTPAddress *postto);
-EMsgComposer * em_utils_reply_to_message (EShell *shell, CamelFolder *, const gchar *uid, CamelMimeMessage *message, gint mode, EMFormat *source);
-EDestination ** em_utils_camel_address_to_destination (CamelInternetAddress *iaddr);
-
-void em_configure_new_composer (struct _EMsgComposer *composer);
+gchar *		em_utils_construct_composer_text
+						(CamelMimeMessage *message,
+						 EMFormat *source);
+gboolean	em_utils_is_munged_list_message	(CamelMimeMessage *message);
+void		em_utils_get_reply_sender	(CamelMimeMessage *message,
+						 CamelInternetAddress *to,
+						 CamelNNTPAddress *postto);
+void		em_utils_get_reply_all		(CamelMimeMessage *message,
+						 CamelInternetAddress *to,
+						 CamelInternetAddress *cc,
+						 CamelNNTPAddress *postto);
+EMsgComposer *	em_utils_reply_to_message	(EShell *shell,
+						 CamelFolder *folder,
+						 const gchar *uid,
+						 CamelMimeMessage *message,
+						 EMailReplyType type,
+						 EMailReplyStyle style,
+						 EMFormat *source);
+EDestination **	em_utils_camel_address_to_destination
+						(CamelInternetAddress *iaddr);
+void		em_configure_new_composer	(EMsgComposer *composer);
 
 G_END_DECLS
 
-#endif /* __EM_COMPOSER_UTILS_H__ */
+#endif /* EM_COMPOSER_UTILS_H */
