@@ -43,7 +43,7 @@ void em_utils_uids_free (GPtrArray *uids);
 
 gboolean em_utils_check_user_can_send_mail (void);
 
-void em_utils_edit_filters (GtkWidget *parent, EMailSession *session);
+void em_utils_edit_filters (GtkWidget *parent, EMailBackend *backend);
 void em_filename_make_safe (gchar *string);
 void em_utils_edit_vfolders (GtkWidget *parent);
 
@@ -72,7 +72,7 @@ gchar *em_utils_get_proxy_uri (const gchar *uri);
 /* FIXME: should this have an override charset? */
 gchar *em_utils_message_to_html (CamelMimeMessage *msg, const gchar *credits, guint32 flags, gssize *len, struct _EMFormat *source, const gchar *append, guint32 *validity_found);
 
-void em_utils_expunge_folder (GtkWidget *parent, CamelFolder *folder);
+void em_utils_expunge_folder (GtkWidget *parent, EMailSession *session, CamelFolder *folder);
 void em_utils_empty_trash (GtkWidget *parent, EMailSession *session);
 
 /* returns the folder name portion of an URI */
@@ -82,10 +82,6 @@ gchar *em_utils_folder_name_from_uri (const gchar *uri);
 gchar *em_uri_from_camel (const gchar *curi);
 gchar *em_uri_to_camel (const gchar *euri);
 
-/* Run errors silently on the status bar */
-void em_utils_show_error_silent (GtkWidget *widget);
-void em_utils_show_info_silent (GtkWidget *widget);
-
 /* is this address in the addressbook?  caches results */
 gboolean em_utils_in_addressbook (CamelInternetAddress *addr, gboolean local_only);
 CamelMimePart *em_utils_contact_photo (CamelInternetAddress *addr, gboolean local);
