@@ -28,7 +28,6 @@
 #include "e-util/e-alert-dialog.h"
 #include "e-util/e-util.h"
 #include "calendar/common/authentication.h"
-#include "calendar/gui/calendar-config.h"
 #include "calendar/gui/e-memo-list-selector.h"
 #include "calendar/gui/misc.h"
 
@@ -54,6 +53,8 @@ struct _EMemoShellSidebarPrivate {
 	 * sometime later we update our default-client property
 	 * which is bound by an EBinding to ECalModel. */
 	ECal *default_client;
+
+	GCancellable *loading_default_client;
 };
 
 enum {
@@ -100,12 +101,24 @@ memo_shell_sidebar_emit_status_message (EMemoShellSidebar *memo_shell_sidebar,
 	g_signal_emit (memo_shell_sidebar, signal_id, 0, status_message, -1.0);
 }
 
+static EAlertSink *
+get_alert_sink (EShellView *shell_view)
+{
+	EShellWindow *shell_window;
+
+	shell_window = e_shell_view_get_shell_window (shell_view);
+
+	if (g_strcmp0 (e_shell_window_get_active_view (shell_window), "calendar") == 0)
+		shell_view = e_shell_window_peek_shell_view (shell_window, "calendar");
+
+	return E_ALERT_SINK (e_shell_view_get_shell_content (shell_view));
+}
+
 static void
 memo_shell_sidebar_backend_died_cb (EMemoShellSidebar *memo_shell_sidebar,
                                     ECal *client)
 {
 	EShellView *shell_view;
-	EShellWindow *shell_window;
 	EShellSidebar *shell_sidebar;
 	GHashTable *client_table;
 	ESource *source;
@@ -115,7 +128,6 @@ memo_shell_sidebar_backend_died_cb (EMemoShellSidebar *memo_shell_sidebar,
 
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
-	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	source = e_cal_get_source (client);
 	uid = e_source_peek_uid (source);
@@ -125,8 +137,7 @@ memo_shell_sidebar_backend_died_cb (EMemoShellSidebar *memo_shell_sidebar,
 	g_hash_table_remove (client_table, uid);
 	memo_shell_sidebar_emit_status_message (memo_shell_sidebar, NULL);
 
-	e_alert_run_dialog_for_args (
-		GTK_WINDOW (shell_window),
+	e_alert_submit (get_alert_sink (shell_view),
 		"calendar:memos-crashed", NULL);
 
 	g_object_unref (source);
@@ -138,35 +149,18 @@ memo_shell_sidebar_backend_error_cb (EMemoShellSidebar *memo_shell_sidebar,
                                      ECal *client)
 {
 	EShellView *shell_view;
-	EShellWindow *shell_window;
 	EShellSidebar *shell_sidebar;
-	GtkWidget *dialog;
-	const gchar *uri;
-	gchar *uri_no_passwd;
+	ESourceGroup *source_group;
+	ESource *source;
 
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
-	shell_window = e_shell_view_get_shell_window (shell_view);
 
-	uri = e_cal_get_uri (client);
-	uri_no_passwd = get_uri_without_password (uri);
+	source = e_cal_get_source (client);
+	source_group = e_source_peek_group (source);
 
-	/* Translators: This string is displayed in a message dialog when
-	 *              our connection to the calendar service detects an
-	 *              out-of-band error.  The first string is a URI for
-	 *              the source of the error, the second string is the
-	 *              error message. */
-	dialog = gtk_message_dialog_new (
-		GTK_WINDOW (shell_window),
-		GTK_DIALOG_DESTROY_WITH_PARENT,
-		GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		_("Error on %s\n%s"),
-		uri_no_passwd, message);
-
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-
-	g_free (uri_no_passwd);
+	e_alert_submit (get_alert_sink (shell_view),
+		"calendar:backend-error", e_source_group_peek_name (source_group), e_source_peek_name (source), message, NULL);
 }
 
 static void
@@ -175,13 +169,11 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
                                      ECal *client)
 {
 	EShellView *shell_view;
-	EShellWindow *shell_window;
 	EShellSidebar *shell_sidebar;
 	const gchar *message;
 
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
-	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	if (g_error_matches (error, E_CALENDAR_ERROR,
 		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
@@ -202,16 +194,14 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 			return;
 
 		case E_CALENDAR_STATUS_REPOSITORY_OFFLINE:
-			e_alert_run_dialog_for_args (
-				GTK_WINDOW (shell_window),
+			e_alert_submit (get_alert_sink (shell_view),
 				"calendar:prompt-no-contents-offline-memos",
 				NULL);
 			/* fall through */
 
 		default:
 			if (error->code != E_CALENDAR_STATUS_REPOSITORY_OFFLINE) {
-				e_alert_run_dialog_for_args (
-					GTK_WINDOW (shell_window),
+				e_alert_submit (get_alert_sink (shell_view),
 					"calendar:failed-open-memos",
 					error->message, NULL);
 			}
@@ -235,104 +225,103 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 }
 
 static void
-memo_shell_sidebar_default_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
-                                      const GError *error,
-                                      ECal *client)
+memo_shell_sidebar_default_loaded_cb (ESource *source,
+                                      GAsyncResult *result,
+                                      EShellSidebar *shell_sidebar)
 {
+	EMemoShellSidebarPrivate *priv;
 	EShellView *shell_view;
-	EShellSidebar *shell_sidebar;
+	ECal *client;
+	GError *error = NULL;
+
+	priv = E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
 
-	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 
-	if (g_error_matches (error, E_CALENDAR_ERROR,
-		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
-	    g_error_matches (error, E_CALENDAR_ERROR,
-		E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED))
-		e_auth_cal_forget_password (client);
+	client = e_load_cal_source_finish (source, result, &error);
 
-	/* Handle errors. */
-	switch (error ? error->code : E_CALENDAR_STATUS_OK) {
-		case E_CALENDAR_STATUS_OK:
-			break;
+	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+		g_error_free (error);
+		goto exit;
 
-		case E_CALENDAR_STATUS_AUTHENTICATION_FAILED:
-			e_cal_open_async (client, FALSE);
-			return;
-
-		case E_CALENDAR_STATUS_BUSY:
-			return;
-
-		default:
-			e_alert_run_dialog_for_args (
-				GTK_WINDOW (e_shell_view_get_shell_window (shell_view)),
-				"calendar:failed-open-memos",
-				error->message, NULL);
-
-			e_memo_shell_sidebar_remove_source (
-				memo_shell_sidebar,
-				e_cal_get_source (client));
-			return;
+	} else if (error != NULL) {
+		e_alert_submit (get_alert_sink (shell_view),
+			"calendar:failed-open-memos",
+			error->message, NULL);
+		g_error_free (error);
+		goto exit;
 	}
 
-	g_assert (error == NULL);
+	g_return_if_fail (E_IS_CAL (client));
 
-	g_signal_handlers_disconnect_matched (
-		client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
-		memo_shell_sidebar_default_opened_cb, NULL);
+	if (priv->default_client != NULL)
+		g_object_unref (priv->default_client);
 
-	g_object_notify (G_OBJECT (memo_shell_sidebar), "default-client");
+	priv->default_client = client;
+
+	g_object_notify (G_OBJECT (shell_sidebar), "default-client");
+
+exit:
+	g_object_unref (shell_sidebar);
 }
 
 static void
 memo_shell_sidebar_set_default (EMemoShellSidebar *memo_shell_sidebar,
                                 ESource *source)
 {
+	EMemoShellSidebarPrivate *priv;
 	EShellView *shell_view;
+	EShellWindow *shell_window;
 	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	EMemoShellContent *memo_shell_content;
 	ECalSourceType source_type;
-	GHashTable *client_table;
 	ECalModel *model;
 	ECal *client;
 	icaltimezone *timezone;
 	const gchar *uid;
 
+	priv = memo_shell_sidebar->priv;
 	source_type = E_CAL_SOURCE_TYPE_JOURNAL;
-	client_table = memo_shell_sidebar->priv->client_table;
-
-	uid = e_source_peek_uid (source);
-	client = g_hash_table_lookup (client_table, uid);
-
-	if (memo_shell_sidebar->priv->default_client != NULL)
-		g_object_unref (memo_shell_sidebar->priv->default_client);
-
-	if (client != NULL)
-		g_object_ref (client);
-	else
-		client = e_auth_new_cal_from_source (source, source_type);
-
-	memo_shell_sidebar->priv->default_client = client;
-	g_return_if_fail (client != NULL);
-
-	g_signal_connect_swapped (
-		client, "cal-opened-ex",
-		G_CALLBACK (memo_shell_sidebar_default_opened_cb),
-		memo_shell_sidebar);
 
 	/* FIXME Sidebar should not be accessing the EShellContent.
 	 *       This probably needs to be moved to EMemoShellView. */
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 	shell_content = e_shell_view_get_shell_content (shell_view);
+	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	memo_shell_content = E_MEMO_SHELL_CONTENT (shell_content);
 	model = e_memo_shell_content_get_memo_model (memo_shell_content);
 	timezone = e_cal_model_get_timezone (model);
 
-	e_cal_set_default_timezone (client, timezone, NULL);
-	e_cal_open_async (client, FALSE);
+	/* Cancel any unfinished previous request. */
+	if (priv->loading_default_client != NULL) {
+		g_cancellable_cancel (priv->loading_default_client);
+		g_object_unref (priv->loading_default_client);
+		priv->loading_default_client = NULL;
+	}
+
+	uid = e_source_peek_uid (source);
+	client = g_hash_table_lookup (priv->client_table, uid);
+
+	/* If we already have an open connection for
+	 * this UID, we can finish immediately. */
+	if (client != NULL) {
+		if (priv->default_client != NULL)
+			g_object_unref (priv->default_client);
+		priv->default_client = g_object_ref (client);
+		g_object_notify (G_OBJECT (shell_sidebar), "default-client");
+		return;
+	}
+
+	priv->loading_default_client = g_cancellable_new ();
+
+	e_load_cal_source_async (
+		source, source_type, timezone,
+		GTK_WINDOW (shell_window), priv->loading_default_client,
+		(GAsyncReadyCallback) memo_shell_sidebar_default_loaded_cb,
+		g_object_ref (shell_sidebar));
 }
 
 static void
@@ -372,12 +361,19 @@ static void
 memo_shell_sidebar_selection_changed_cb (EMemoShellSidebar *memo_shell_sidebar,
                                          ESourceSelector *selector)
 {
+	EShellView *shell_view;
+	EShellBackend *shell_backend;
+	EShellSidebar *shell_sidebar;
 	GSList *list, *iter;
 
 	/* This signal is emitted less frequently than "row-changed",
 	 * especially when the model is being rebuilt.  So we'll take
 	 * it easy on poor GConf. */
 
+	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
+	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
+
 	list = e_source_selector_get_selection (selector);
 
 	for (iter = list; iter != NULL; iter = iter->next) {
@@ -387,7 +383,8 @@ memo_shell_sidebar_selection_changed_cb (EMemoShellSidebar *memo_shell_sidebar,
 		g_object_unref (source);
 	}
 
-	calendar_config_set_memos_selected (list);
+	e_memo_shell_backend_set_selected_memo_lists (
+		E_MEMO_SHELL_BACKEND (shell_backend), list);
 
 	g_slist_free (list);
 }
@@ -396,31 +393,12 @@ static void
 memo_shell_sidebar_primary_selection_changed_cb (EMemoShellSidebar *memo_shell_sidebar,
                                                  ESourceSelector *selector)
 {
-	EShell *shell;
-	EShellView *shell_view;
-	EShellWindow *shell_window;
-	EShellSidebar *shell_sidebar;
-	EShellSettings *shell_settings;
 	ESource *source;
 
-	/* XXX ESourceSelector needs a "primary-selection-uid" property
-	 *     so we can just bind the property with GConfBridge. */
-
-	source = e_source_selector_peek_primary_selection (selector);
+	source = e_source_selector_get_primary_selection (selector);
 	if (source == NULL)
 		return;
 
-	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
-	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
-	shell_window = e_shell_view_get_shell_window (shell_view);
-
-	shell = e_shell_window_get_shell (shell_window);
-	shell_settings = e_shell_get_shell_settings (shell);
-
-	e_shell_settings_set_string (
-		shell_settings, "cal-primary-memo-list",
-		e_source_peek_uid (source));
-
 	memo_shell_sidebar_set_default (memo_shell_sidebar, source);
 }
 
@@ -438,7 +416,6 @@ memo_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 	ESource *source;
 	GtkTreeModel *model;
 	GSList *list, *iter;
-	gchar *uid;
 
 	priv = E_MEMO_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
 
@@ -464,28 +441,29 @@ memo_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 		G_CALLBACK (memo_shell_sidebar_primary_selection_changed_cb),
 		shell_sidebar);
 
-	source = NULL;
-	uid = e_shell_settings_get_string (
-		shell_settings, "cal-primary-memo-list");
-	if (uid != NULL)
-		source = e_source_list_peek_source_by_uid (source_list, uid);
-	if (source == NULL)
-		source = e_source_list_peek_source_any (source_list);
-	if (source != NULL)
-		e_source_selector_set_primary_selection (selector, source);
-	g_free (uid);
+	g_object_bind_property_full (
+		shell_settings, "cal-primary-memo-list",
+		selector, "primary-selection",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE,
+		(GBindingTransformFunc) e_binding_transform_uid_to_source,
+		(GBindingTransformFunc) e_binding_transform_source_to_uid,
+		g_object_ref (source_list),
+		(GDestroyNotify) g_object_unref);
+
+	list = e_memo_shell_backend_get_selected_memo_lists (
+		E_MEMO_SHELL_BACKEND (shell_backend));
 
-	list = calendar_config_get_memos_selected ();
 	for (iter = list; iter != NULL; iter = iter->next) {
-		uid = iter->data;
+		const gchar *uid = iter->data;
+
 		source = e_source_list_peek_source_by_uid (source_list, uid);
-		g_free (uid);
 
-		if (source == NULL)
-			continue;
-
-		e_source_selector_select_source (selector, source);
+		if (source != NULL)
+			e_source_selector_select_source (selector, source);
 	}
+
+	g_slist_foreach (list, (GFunc) g_free, NULL);
 	g_slist_free (list);
 
 	/* Listen for subsequent changes to the selector. */
@@ -538,6 +516,12 @@ memo_shell_sidebar_dispose (GObject *object)
 		priv->default_client = NULL;
 	}
 
+	if (priv->loading_default_client != NULL) {
+		g_cancellable_cancel (priv->loading_default_client);
+		g_object_unref (priv->loading_default_client);
+		priv->loading_default_client = NULL;
+	}
+
 	g_hash_table_remove_all (priv->client_table);
 
 	/* Chain up to parent's dispose() method. */
@@ -625,7 +609,7 @@ memo_shell_sidebar_check_state (EShellSidebar *shell_sidebar)
 
 	memo_shell_sidebar = E_MEMO_SHELL_SIDEBAR (shell_sidebar);
 	selector = e_memo_shell_sidebar_get_selector (memo_shell_sidebar);
-	source = e_source_selector_peek_primary_selection (selector);
+	source = e_source_selector_get_primary_selection (selector);
 
 	if (source != NULL) {
 		ECal *client;
