@@ -37,6 +37,9 @@
 
 #include "google-contacts-source.h"
 
+/* backward-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 void
 ensure_google_contacts_source_group (void)
 {
@@ -91,7 +94,9 @@ on_username_entry_changed (GtkEntry *entry, gpointer user_data)
 
 	text = gtk_entry_get_text (entry);
 
-	if (strstr (text, "@")) {
+	if (!text || !*text) {
+		username = NULL;
+	} else if (strstr (text, "@")) {
 		username = g_strdup (text);
 	} else {
 		username = g_strdup_printf ("%s@gmail.com", text);
@@ -204,6 +209,41 @@ on_interval_combo_changed (GtkComboBox *combo, gpointer user_data)
 	g_free (value_string);
 }
 
+gpointer
+check_username_filled (ESource *source)
+{
+	gboolean res = TRUE;
+
+	g_return_val_if_fail (source != NULL, NULL);
+
+	if (g_ascii_strncasecmp (GOOGLE_BASE_URI, e_source_group_peek_base_uri (e_source_peek_group (source)), strlen (GOOGLE_BASE_URI)) == 0) {
+		gchar *username = g_strdup (e_source_get_property (source, "username"));
+
+		if (username)
+			username = g_strstrip (username);
+
+		res = username && *username;
+
+		g_free (username);
+	}
+
+	return GINT_TO_POINTER (res ? 1 : 0);
+}
+
+gpointer
+plugin_google_contacts_check (EPlugin *epl, EConfigHookPageCheckData *data)
+{
+	EABConfigTargetSource *t;
+
+	g_return_val_if_fail (data != NULL, NULL);
+	g_return_val_if_fail (data->target != NULL, NULL);
+
+	t = (EABConfigTargetSource *) data->target;
+	g_return_val_if_fail (t->source != NULL, NULL);
+
+	return 	check_username_filled (t->source);
+}
+
 struct ui_data {
 	GtkWidget *widget;
 };
@@ -259,7 +299,7 @@ plugin_google_contacts (EPlugin *epl,
 
 	g_object_set_data (G_OBJECT (epl), "gwidget", NULL);
 
-	if (g_ascii_strncasecmp ("google://", base_uri, 9) != 0)
+	if (g_ascii_strncasecmp (GOOGLE_BASE_URI, base_uri, 9) != 0)
 		return NULL;
 
 	/* Build up the UI */
@@ -330,11 +370,11 @@ plugin_google_contacts (EPlugin *epl,
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (interval_sb), time);
 	gtk_box_pack_start (GTK_BOX (hbox), interval_sb, FALSE, FALSE, 0);
 
-	interval_combo = gtk_combo_box_new_text ();
-	gtk_combo_box_append_text (GTK_COMBO_BOX (interval_combo), _("minutes"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (interval_combo), _("hours"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (interval_combo), _("days"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (interval_combo), _("weeks"));
+	interval_combo = gtk_combo_box_text_new ();
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (interval_combo), _("minutes"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (interval_combo), _("hours"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (interval_combo), _("days"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (interval_combo), _("weeks"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (interval_combo), type);
 	gtk_box_pack_start (GTK_BOX (hbox), interval_combo, FALSE, FALSE, 0);
 
